@@ -1,15 +1,13 @@
 """
 Perform a source reversion on the projects within a checkout.
 
-Copyright (c) 2007 by Enthought, Inc.
+Copyright (c) 2007-2009 by Enthought, Inc.
 License: BSD Style.
 
 """
 
-# Standard library imports
 import os
 
-# Project library imports
 from enthought.ets.base_subcommand import BaseSubcommand
 from enthought.ets.tools.checkouts import Checkouts
 
@@ -49,7 +47,7 @@ class Revert(BaseSubcommand):
 
     def main(self, args, cfg):
         """
-        Build each project within a checkout.
+        Preform this command.
 
         """
 
@@ -57,16 +55,15 @@ class Revert(BaseSubcommand):
         if args.path is None or len(args.path) < 1:
             args.path = [os.getcwd()]
 
-        # Create a record of the svn checkout directories under the
-        # user-specified paths.
+        # Create a record of the projects within the user-specified checkouts.
         checkouts = Checkouts(args.path, verbose=args.verbose)
 
-        # Perform an svn update command against all checkouts.
+        # Perform the command against those projects.
         command = ['svn', 'revert']
         if len(args.command_args) > 0:
             command.extend(self.split_command_line_args(args.command_args))
         command.append('.')
-        checkouts.perform(command, dry_run=args.dry_run)
+        checkouts.perform(command, dry_run=args.dry_run, required_files=[])
 
         return
 
